==> confidence-hamcrest-0.43.0-sources.jar: org/saynotobugs/confidence/hamcrest/matcher/QualifiesAs.java <==
/*
 * Copyright 2024 dmfs GmbH
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.saynotobugs.confidence.hamcrest.matcher;

import org.dmfs.srcless.annotations.staticfactory.StaticFactories;
import org.hamcrest.Description;
import org.hamcrest.TypeSafeDiagnosingMatcher;
import org.saynotobugs.confidence.Assessment;
import org.saynotobugs.confidence.Quality;
import org.saynotobugs.confidence.Scribe;
import org.saynotobugs.confidence.scribe.StringBuilderScribe;

/**
 * A Hamcrest {@link org.hamcrest.Matcher} of {@code T} that delegates to a {@link Quality}.
 */
@StaticFactories(value = "Hamcrest", packageName = "org.saynotobugs.confidence.hamcrest")
public final class QualifiesAs<T> extends TypeSafeDiagnosingMatcher<T>
{
    private final Quality<? super T> mQuality;

    public QualifiesAs(Quality<? super T> quality)
    {
        mQuality = quality;
    }

    @Override
    protected boolean matchesSafely(T item, Description mismatchDescription)
    {
        Scribe scribe = new StringBuilderScribe("");
        Assessment assessment = mQuality.assessmentOf(item);
        assessment.description().describeTo(scribe);
        mismatchDescription.appendText(scribe.toString());
        return assessment.isSuccess();
    }

    @Override
    public void describeTo(Description description)
    {
        Scribe scribe = new StringBuilderScribe("");
        mQuality.description().describeTo(scribe);
        description.appendText(scribe.toString());
    }
}

==> confidence-hamcrest-0.55.1-sources.jar: org/saynotobugs/confidence/hamcrest/matcher/QualifiesAs.java <==
/*
 * Copyright 2024 dmfs GmbH
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.saynotobugs.confidence.hamcrest.matcher;

import org.dmfs.srcless.annotations.staticfactory.DeprecatedFactories;
import org.dmfs.srcless.annotations.staticfactory.StaticFactories;
import org.hamcrest.Description;
import org.hamcrest.TypeSafeDiagnosingMatcher;
import org.saynotobugs.confidence.Assessment;
import org.saynotobugs.confidence.Quality;
import org.saynotobugs.confidence.Scribe;
import org.saynotobugs.confidence.scribe.StringBuilderScribe;

/**
 * A Hamcrest {@link org.hamcrest.Matcher} of {@code T} that delegates to a {@link Quality}.
 */
@StaticFactories(
    value = "Adapter",
    packageName = "org.saynotobugs.confidence.hamcrest.matcher",
    deprecates = @DeprecatedFactories(value = "Hamcrest", packageName = "org.saynotobugs.confidence.hamcrest"))
public final class QualifiesAs<T> extends TypeSafeDiagnosingMatcher<T>
{
    private final Quality<? super T> mQuality;

    public QualifiesAs(Quality<? super T> quality)
    {
        mQuality = quality;
    }

    @Override
    protected boolean matchesSafely(T item, Description mismatchDescription)
    {
        Scribe scribe = new StringBuilderScribe("");
        Assessment assessment = mQuality.assessmentOf(item);
        assessment.description().describeTo(scribe);
        mismatchDescription.appendText(scribe.toString());
        return assessment.isSuccess();
    }

    @Override
    public void describeTo(Description description)
    {
        Scribe scribe = new StringBuilderScribe("");
        mQuality.description().describeTo(scribe);
        description.appendText(scribe.toString());
    }
}
